@@ -83,29 +83,19 @@ class TradeUpdate:
             symbol=symbol, period='1year', size=2000).dict_data['data'], symbol))
 
     def auto_save(self):
+        self.symbolDB.auto_save()
         self.tradeDB.auto_save()
         self.kline_1min.auto_save()
         self.kline_5min.auto_save()
         self.kline_15min.auto_save()
         self.kline_30min.auto_save()
+        self.kline_60min.auto_save()
         self.kline_4hour.auto_save()
         self.kline_1day.auto_save()
         self.kline_1mon.auto_save()
         self.kline_1week.auto_save()
         self.kline_1year.auto_save()
 
-    def _save(self):
-        self.tradeDB._save(pop=False)
-        self.kline_1min._save(pop=False)
-        self.kline_5min._save(pop=False)
-        self.kline_15min._save(pop=False)
-        self.kline_30min._save(pop=False)
-        self.kline_4hour._save(pop=False)
-        self.kline_1day._save(pop=False)
-        self.kline_1mon._save(pop=False)
-        self.kline_1week._save(pop=False)
-        self.kline_1year._save(pop=False)
-
     def insert_data(self, trade=True, kline=True):
         symbols = self.symbolDB.select("select symbol from {} where state ='online'".format(self.symbolDB.table_name))
         for symbol in tqdm(symbols):
@@ -136,15 +126,12 @@ class TradeUpdate:
 
         while True:
             self.insert_symbol()
-            if t % 10 == 0:
-                self._save()
-
             if t % 100 == 0:
                 self.insert_data(trade=True, kline=True)
                 self.auto_save()
             else:
                 self.insert_data(trade=True, kline=False)
-                time.sleep(60)
+                time.sleep(120)
             t += 1
 
     def test(self):
